pyFlarum Python package - provides an easy access to Flarum's API.

(c) Kevo 2021

You are allowed to modify any parts of this program, as long as this
notice stays on its place, without any modifications. It is that simple
to support my hard work. Thank you for using this.

    - PyPi: https://pypi.org/project/pyFlarum/
    - Official Flarum website: https://flarum.org
